Pyramid Class-Based Views — Pyramid Class-Based Views 1.0 documentation

# Pyramid Class-Based Views

- Introduction
  - Class-based generic views?
  - Why?
  - Differences from Django
- Future Development
- API Reference
  - View
  - Redirect View
  - Template View
  - List View
  - Detail View
  - Form View
  - Create View
  - Update View
  - Delete View

This site documents pyramid-views, a Pyramid port of Django’s class-based generic views.

Note

Note that the most complete documentation will be Django’s class-based view reference documentation. You may also find the Django’s class-based view introductory documentation useful.

See also:

- Django’s class-based view introductory documentation
- Django’s class-based view reference documentation
- GitHub
- PyPi